@@ -15,6 +15,7 @@ console.log('\n Testing decimal.js\n');
   'atanh',
   'cbrt',
   'ceil',
+  'clamp',
   'clone',
   'cmp',
   'config',
@@ -46,6 +47,7 @@ console.log('\n Testing decimal.js\n');
   'sin',
   'sinh',
   'sqrt',
+  'sum',
   'tan',
   'tanh',
   'times',
